<?php
namespace FiloBlu\Flow\Block\Adminhtml\Channel\Edit\Tab;
class Parser extends \Magento\Backend\Block\Widget\Form\Generic implements \Magento\Backend\Block\Widget\Tab\TabInterface
{
    /**
     * @var \Magento\Store\Model\System\Store
     */
    protected $_systemStore;

    /**
     * @param \Magento\Backend\Block\Template\Context $context
     * @param \Magento\Framework\Registry $registry
     * @param \Magento\Framework\Data\FormFactory $formFactory
     * @param \Magento\Store\Model\System\Store $systemStore
     * @param array $data
     */

    public function __construct(
        \Magento\Backend\Block\Template\Context $context,
        \Magento\Framework\Registry $registry,
        \Magento\Framework\Data\FormFactory $formFactory,
        \Magento\Store\Model\System\Store $systemStore,
        \FiloBlu\Flow\Helper\Data $helper,
        array $data = array()
    ) {
        $this->_systemStore = $systemStore;
        $this->helper = $helper;
        parent::__construct($context, $registry, $formFactory, $data);
    }
    /**
     * Prepare form
     *
     * @return $this
     */
    protected function _prepareForm()
    {
        /* @var $model \Magento\Cms\Model\Page */
        $model = $this->_coreRegistry->registry('flow_channel');
        /** @var \Magento\Framework\Data\Form $form */
        $form = $this->_formFactory->create();

        $form->setHtmlIdPrefix('page_');

        $fieldset_parser = $form->addFieldset('parser_fieldset', array('legend' => __('Parser Map')));

        $fieldset_parser->addField("type", "text", array(
            "label" => __("Type"),
            "name" => "parser[type]",
        ));

        $fieldset_parser->addField("separator", "text", array(
            "label" => __("Separator"),
            "name" => "parser[separator]",
        ));

        $fieldset_parser->addField("delimiter", "text", array(
            "label" => __("Delimiter"),
            "name" => "parser[delimiter]",
        ));

        $fieldset_parser->addField("lines_to_skip", "select", array(
            "label" => __("Header in first line"),
            "name" => "parser[lines_to_skip]",
            'values' => array('0'=>'No','1'=>'Yes'),
        ));

        $afterElementHtml = '&nbsp;<small>' . ' Per Flow di tipo Anagrafica: controllo sul numero di colonne? Se impostato a NO, posso importare un csv con un numero di attributi inferiore a quelli mappati nel json - Header in first line deve essere YES' . '</small>';
        $copy_to_ite = $fieldset_parser->addField('check_mapping_count', 'select', array(
                'name' => 'config[check_mapping_count]',
                'label' => __('Check mapping count'),
                'required' => false,
                'values' => array('0'=>'No','1'=>'Yes'),
                'default' => 0,
                'after_element_html' => $afterElementHtml
            )
        );

        $fieldset_parser->addField("prehook", "text", array(
            "label" => __("Prehook"),
            "name" => "parser[prehook]",
        ));

        $fieldset_parser->addField("posthook", "text", array(
            "label" => __("Posthook"),
            "name" => "parser[posthook]",
        ));

        $form->setValues($model->getData('parser'));
        $this->setForm($form);

        return parent::_prepareForm();
    }

    /**
     * Prepare label for tab
     *
     * @return string
     */
    public function getTabLabel()
    {
        return __('Parser');
    }

    /**
     * Prepare title for tab
     *
     * @return string
     */
    public function getTabTitle()
    {
        return __('parser');
    }

    /**
     * {@inheritdoc}
     */
    public function canShowTab()
    {
        return true;
    }

    /**
     * {@inheritdoc}
     */
    public function isHidden()
    {
        return false;
    }

    /**
     * Check permission for passed action
     *
     * @param string $resourceId
     * @return bool
     */
    protected function _isAllowedAction($resourceId)
    {
        return $this->_authorization->isAllowed($resourceId);
    }

}
