<?php
/**
 * Copyright © 2015 FiloBlu . All rights reserved.
 */

namespace FiloBlu\Flow\Helper;

/**
 * Class Data
 * @package FiloBlu\Flow\Helper
 */
class Data extends \Magento\Framework\App\Helper\AbstractHelper
{
    /**
     * @var
     */
    protected $_storesByLocale;
    /**
     * @var \Magento\Framework\DB\Adapter\AdapterInterface
     */
    protected $_connection;

    /**
     * @param \Magento\Framework\App\Helper\Context $context
     */
    public function __construct(
        \Magento\Framework\App\Helper\Context $context,
        \Magento\Framework\App\ResourceConnection $_connection
    ) {
        $this->_connection = $_connection->getConnection();
        parent::__construct($context);

    }

    /**
     * @return mixed
     */
    public function getModels()
    {
        $channels_in = (Array)$this->scopeConfig->getValue('processor/channels/in');
        $channels_out = (Array)$this->scopeConfig->getValue('processor/channels/out');

        $classes['select'] = '';

        foreach ($channels_in as $key => $channel) {
            $classes[$channel] = $key;
        }

        foreach ($channels_out as $key => $channel) {
            $classes[$channel] = $key;
        }

        return $classes;

    }

    /**
     * @param $channel_input
     * @return int|string|void
     */
    public function getChannelModels($channel_input)
    {
        $channels_in = (Array)$this->scopeConfig->getValue('processor/channels/in');

        foreach ($channels_in as $key => $channel) {
            if ($channel == $channel_input) {
                return $key;
            }
        }

        return;
    }

    /**
     * @param $id_inboundflow
     * @return array
     */
    public function getChannelByInbound($id_inboundflow)
    {
        if ($id_inboundflow > 0) {

            $query = "SELECT * FROM flow_inboundflow WHERE id = ? LIMIT 1";
            $result = $this->_connection->fetchRow($query, [$id_inboundflow]);

            if (count($result) > 0) {
                return $result;
            }
        }

        return array();
    }

    /**
     * @param $filepath
     * @return array
     */
    public function file_get_php_classes($filepath)
    {
        $php_code = file_get_contents($filepath);
        $classes = $this->get_php_classes($php_code);
        return $classes;
    }

    /**
     * @param $php_code
     * @return array
     */
    public function get_php_classes($php_code)
    {
        $tokens = token_get_all($php_code);
        $count = count($tokens);
        for ($i = 2; $i < $count; $i++) {
            if ($tokens[$i - 2][0] == T_CLASS
                && $tokens[$i - 1][0] == T_WHITESPACE
                && $tokens[$i][0] == T_STRING) {

                $class_name = $tokens[$i][1];
                $key = $end = end(explode('_', $class_name));
                if ($key != 'Abstract') {
                    return $class_name;
                }
            }
        }
        return array();
    }

    /**
     * @param $text
     * @return string
     */
    public function removeTextSpaces($text)
    {
        $result = preg_replace("/\s/u", "", $text);
        $result = preg_replace("/( )+/u", "", $result);
        return trim($result);
    }

    /**
     * @return array
     */
    public function getAllStoreIds()
    {

        $storeIds = array();

        /** @var \Magento\Framework\App\ObjectManager $om */
        $om = \Magento\Framework\App\ObjectManager::getInstance();
        /** @var \Magento\Store\Model\StoreManagerInterface|\Magento\Store\Model\StoreManager $storeManager */
        $storeManager = $om->get('Magento\Store\Model\StoreManagerInterface');
        $_list_stores = $storeManager->getStores($withDefault = true);

        foreach ($_list_stores as $store) {
            $storeIds[$store->getCode()] = $store->getId();
        }

        return $storeIds;
    }

    /**
     * @return array
     */
    public function getStoreInWebsiteId()
    {

        $storeIds = array();

        /** @var \Magento\Framework\App\ObjectManager $om */
        $om = \Magento\Framework\App\ObjectManager::getInstance();
        /** @var \Magento\Store\Model\StoreManagerInterface|\Magento\Store\Model\StoreManager $storeManager */
        $storeManager = $om->get('Magento\Store\Model\StoreManagerInterface');

        $_list_stores = $storeManager->getStores($withDefault = true);
        $_list_websites = $storeManager->getWebsites($withDefault = true);

        foreach ($_list_websites as $website) {
            foreach ($_list_stores as $store) {
                if ($website->getId() == $store->getWebsiteId()) {
                    $storeIds[$website->getCode()] = array(
                        "store_id" => $store->getId()
                    );
                    break;
                }
            }
        }

        return $storeIds;
    }

    /**
     * @return array
     */
    public function getAllStoresCodeByLocale()
    {

        $objectManager = \Magento\Framework\App\ObjectManager::getInstance();

        $storeManager = $objectManager->get('Magento\Store\Model\StoreManagerInterface');
        $stores = $storeManager->getStores($withDefault = false);

        $scopeConfig = $objectManager->get('Magento\Framework\App\Config\ScopeConfigInterface');

        //Locale code
        $storesByLocale = [];

        //Try to get list of locale for all stores;
        foreach ($stores as $store) {
            $localeCode = $scopeConfig->getValue('general/locale/code',
                \Magento\Store\Model\ScopeInterface::SCOPE_STORE, $store->getStoreId());
            $localeCode = substr($localeCode, 0, 2);
            $storeCode = $store->getCode();
            $storesByLocale[$localeCode][] = $storeCode;
        }


        return $storesByLocale;
    }

    /**
     * @param $locale
     * @return array|mixed
     */
    public function getStoresCodeByLocale($locale)
    {

        if ($locale == '') {
            return array();
        }

        if (count($this->_storesByLocale) == 0) {

            $objectManager = \Magento\Framework\App\ObjectManager::getInstance();

            $storeManager = $objectManager->get('Magento\Store\Model\StoreManagerInterface');
            $stores = $storeManager->getStores($withDefault = false);

            $scopeConfig = $objectManager->get('Magento\Framework\App\Config\ScopeConfigInterface');

            //Locale code
            $this->_storesByLocale = [];

            //Try to get list of locale for all stores;
            foreach ($stores as $store) {
                $localeCode = $scopeConfig->getValue('general/locale/code',
                    \Magento\Store\Model\ScopeInterface::SCOPE_STORE, $store->getStoreId());
                $localeCode = substr($localeCode, 0, 2);

                if (!isset($this->_storesByLocale[$localeCode])) {
                    $this->_storesByLocale[$localeCode] = array();
                }
                $storeCode = $store->getCode();
                $this->_storesByLocale[$localeCode][] = $storeCode;
            }
        }

        if (isset($this->_storesByLocale[$locale])) {
            return $this->_storesByLocale[$locale];
        }
        return array();
    }


    public function getSkeleton()
    {
        return str_replace(array("\n", ' '), '',
            '{"field":{"from":"","to":"","type":"text","validators":[],"filters":[],"stores":"","locale":"","actions":[]} }');

    }
}
