<?php
/**
 * Copyright © 2015 FiloBlu . All rights reserved.
 */
namespace FiloBlu\Flow\Helper;

class Product extends \Magento\Framework\App\Helper\AbstractHelper
{
    protected $scopeConfig;
    const CONFIG_FLOW_ATTRIBUTE_PATH = 'filoblu_flow/flow_process/flow_attribute_select';
    const CONFIG_FLOW_ONLYCONFIGURABLE_PATH = 'filoblu_flow/flow_process/flow_only_configurable_category';
    const CONFIG_FLOW_UPDATECATEGORY_PATH = 'filoblu_flow/flow_process/flow_update_category';
    const CONFIG_FLOW_MERGE_PATH = 'filoblu_flow/flow_process/flow_merge_category';
    const CONFIG_FLOW_ASSIGN_ROOT_CAT = 'filoblu_flow/flow_process/flow_assign_root_categories';
    const CONFIG_FLOW_ASSIGN_FULL_TREE_PATH = 'filoblu_flow/flow_process/flow_assign_full_tree_category';
    const CONFIG_FLOW_UPDATE_CONFIGURABLE_URL = 'filoblu_flow/flow_process/flow_configurable_url';
    const CONFIG_FLOW_ADD_TO_ALL_WEBSITES = 'filoblu_flow/flow_ite/add_to_websites';

    public function __construct(\Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig)
    {
        $this->scopeConfig = $scopeConfig;
    }

    // Import categories only on configurables?
    public function getOnlyConfigurableCategoryFlag(){

        $storeScope = \Magento\Store\Model\ScopeInterface::SCOPE_WEBSITE;
        $flag = $this->scopeConfig->getValue(self::CONFIG_FLOW_ONLYCONFIGURABLE_PATH, $storeScope);

        return $flag;
    }

    // Is process categories enabled?
    public function processCategoriesEnabledFlag(){
        $storeScope = \Magento\Store\Model\ScopeInterface::SCOPE_WEBSITE;
        $flag = $this->scopeConfig->getValue(self::CONFIG_FLOW_UPDATECATEGORY_PATH, $storeScope);

        return $flag;
    }

    // Categories need to be merged with the old ones?
    public function mergeCategoriesFlag(){
        $storeScope = \Magento\Store\Model\ScopeInterface::SCOPE_WEBSITE;
        $flag = $this->scopeConfig->getValue(self::CONFIG_FLOW_MERGE_PATH, $storeScope);

        return $flag;
    }

    // Assign product also on root categories? (level 1 categories on database)
    public function assignRootCategories(){
        $storeScope = \Magento\Store\Model\ScopeInterface::SCOPE_WEBSITE;
        $flag = $this->scopeConfig->getValue(self::CONFIG_FLOW_ASSIGN_ROOT_CAT, $storeScope);

        return $flag;
    }

    // Do I need to assign the product to the full category tree?
    public function assignFullTree(){
        $storeScope = \Magento\Store\Model\ScopeInterface::SCOPE_WEBSITE;
        $flag = $this->scopeConfig->getValue(self::CONFIG_FLOW_ASSIGN_FULL_TREE_PATH, $storeScope);

        return $flag;
    }

    public function getUpdateConfigurableUrl(){

        $storeScope = \Magento\Store\Model\ScopeInterface::SCOPE_WEBSITE;
        $flag = $this->scopeConfig->getValue(self::CONFIG_FLOW_UPDATE_CONFIGURABLE_URL, $storeScope);

        return $flag;
    }

    public function getProductAttributeSet(){
        return 4;
    }

    public function createNewProducts(){
        return true;
    }

    public function getInitialProductStatus(){
        return \Magento\Catalog\Model\Product\Attribute\Source\Status::STATUS_DISABLED;
    }

    public function getAddToWebsites(){
        return $this->scopeConfig->getValue(self::CONFIG_FLOW_ADD_TO_ALL_WEBSITES);
    }

    public function getMappedTaxClassId($TaxClassCode){
        return 2;
    }

    public function getParentProductsIds($childProducts){
        $relationTableName = \Magento\Framework\App\ObjectManager::getInstance()->get('\Magento\Framework\App\ResourceConnection')->getTableName('catalog_product_super_link');

        $products = \Magento\Framework\App\ObjectManager::getInstance()->create('Magento\Catalog\Model\ResourceModel\Product\Collection');

        $products->getSelect()->join(array('super_link'=> $relationTableName), 'e.entity_id = super_link.parent_id');
        $products->getSelect()->where('super_link.product_id IN (?)', $childProducts);
        //$products->addFieldToFilter('type_id', $productType);
        $products->getSelect()->group('e.entity_id');

        return $products->getAllIds();
    }

    /**
     * @return array
     */
    public function getSimpleToConfigurableProductAttributesToExclude(){
        $saved = [];

        if(is_string($saved)){
            return explode(",", $saved);
        }

        return $saved;
    }

    /**
     * @return array
     */
    public function getSimpleToConfigurableSyncAttributes(){

        /*
        $attributesToCopy = \Magento\Framework\App\ObjectManager::getInstance()->create('FiloBlu\Flow\Model\System\ProductAttributes')->getAttributesToCopy()->getColumnValues('attribute_code');
        $excludedAttributes = $this->getSimpleToConfigurableProductAttributesToExclude();
        $attributesToCopy = array_diff($attributesToCopy, $excludedAttributes);
        */

        $storeScope = \Magento\Store\Model\ScopeInterface::SCOPE_WEBSITE;

        $attributesToCopy = $this->scopeConfig->getValue(self::CONFIG_FLOW_ATTRIBUTE_PATH, $storeScope);//array("name", "description", "short_description");

        if(!empty($attributesToCopy)) {
            return explode(",", $attributesToCopy);
        }

        return [];
    }

    /**
     * @return bool
     */
    public function getUpdateConfigurablePrice(){
        return false;
    }

}
